@@ -10,7 +10,7 @@ from web3 import Web3
 from zero_ex.contract_wrappers import TxParams
 
 
-class BaseModule:
+class _BaseModule:
     get_client: Optional[Callable[[], Web3]]
     get_storage: Optional[Callable[[], IpfsStorage]]
     get_signer_address: Optional[Callable[[], str]]
