@@ -1,14 +1,14 @@
 from ..errors import NoSignerException
 from ..types import Role
 from ..abi.coin import Coin
-from .base import BaseModule
-from .currency_types import Currency, CurrencyValue
+from .base import _BaseModule
+from ..types.currency import Currency, CurrencyValue
 from ..abi.erc20 import ERC20
 from web3 import Web3
 from typing import List, Dict
 
 
-class CurrencyModule(BaseModule):
+class CurrencyModule(_BaseModule):
     address: str
     __abi_module: Coin
 
