@@ -3,16 +3,17 @@ import copy
 import json
 
 from web3 import Web3
+from zero_ex.contract_wrappers import TxParams
 
-from . import BaseModule
+from .base import _BaseModule
 from typing import Dict, List
 from ..abi.nft import NFT
 
-from ..types import NFT as NftType, Role
-from .nft_types import MintArg
+from ..types import Role
+from ..types.nft import MintArg, NftMetadata as NftType
 
 
-class NftModule(BaseModule):
+class NftModule(_BaseModule):
     address: str
     __abi_module: NFT
 
@@ -21,14 +22,14 @@ class NftModule(BaseModule):
         self.address = address
         self.__abi_module = NFT(client, address)
 
-    def mint(self, arg: MintArg):
-        return self.mint_to(self.get_signer_address(), arg)
+    def mint(self, arg: MintArg) -> NftType:
+        return self.mint_to(self.__get_signer_address(), arg)
 
     def mint_to(
             self,
             to_address: str,
             arg: MintArg,
-    ):
+    ) -> NftType:
         final_properties: Dict
         if arg.properties is None:
             final_properties = {}
@@ -43,15 +44,15 @@ class NftModule(BaseModule):
             'properties': final_properties
         }
 
-        uri = storage.upload(json.dumps(meta), self.address, self.get_signer_address())
-        tx = self.__abi_module.mint_nft.build_transaction(to_address, uri, self.get_transact_opts())
+        uri = storage.upload(json.dumps(meta), self.address, self.__get_signer_address())
+        tx = self.__abi_module.mint_nft.build_transaction(to_address, uri, self.__get_transact_opts())
         receipt = self.execute_tx(tx)
         result = self.__abi_module.get_minted_event(tx_hash=receipt.transactionHash.hex())
         token_id = result[0]['args']['tokenId']
         return self.get(token_id)
 
     def total_supply(self) -> int:
-        return self.__abi_module.total_supply.call()
+        return self.__abi_module.total_supply.call(tx_params=TxParams(from_=self.address))
 
     def get(self, nft_id: int) -> NftType:
         return self.__get_metadata(nft_id)
@@ -71,7 +72,7 @@ class NftModule(BaseModule):
         return uri
 
     def mint_batch(self, args: List[MintArg]):
-        return self.mint_batch_to(self.get_signer_address(), args)
+        return self.mint_batch_to(self.__get_signer_address(), args)
 
     def mint_batch_to(self, to_address: str, args: List[MintArg]):
         uris = [self.get_storage().upload(json.dumps({
@@ -79,9 +80,9 @@ class NftModule(BaseModule):
             'description': arg.description,
             'image': arg.image_uri,
             'properties': arg.properties if arg.properties is not None else {}
-        }), self.address, self.get_signer_address()) for arg in args]
+        }), self.address, self.__get_signer_address()) for arg in args]
 
-        tx = self.__abi_module.mint_nft_batch.build_transaction(to_address, uris, self.get_transact_opts())
+        tx = self.__abi_module.mint_nft_batch.build_transaction(to_address, uris, self.__get_transact_opts())
 
         receipt = self.execute_tx(tx)
         result = self.__abi_module.get_minted_batch_event(tx_hash=receipt.transactionHash.hex())
@@ -91,7 +92,7 @@ class NftModule(BaseModule):
     def burn(self, token_id: int):
         tx = self.__abi_module.burn.build_transaction(
             token_id,
-            self.get_transact_opts()
+            self.__get_transact_opts()
         )
         self.execute_tx(tx)
 
@@ -100,7 +101,7 @@ class NftModule(BaseModule):
             from_address,
             to_address,
             token_id,
-            self.get_transact_opts()
+            self.__get_transact_opts()
         )
         self.execute_tx(tx)
 
@@ -109,15 +110,15 @@ class NftModule(BaseModule):
     """
     def transfer(self, to_address: str, token_id: int):
         tx = self.__abi_module.safe_transfer_from1.build_transaction(
-            self.get_signer_address(),
+            self.__get_signer_address(),
             to_address,
             token_id,
-            self.get_transact_opts()
+            self.__get_transact_opts()
         )
         self.execute_tx(tx)
 
     def set_royalty_bps(self, amount: int):
-        tx = self.__abi_module.set_royalty_bps.build_transaction(amount, self.get_transact_opts())
+        tx = self.__abi_module.set_royalty_bps.build_transaction(amount, self.__get_transact_opts())
         self.execute_tx(tx)
 
     def get_all(self) -> List[NftType]:
@@ -130,7 +131,7 @@ class NftModule(BaseModule):
     """
     def get_owned(self, address: str = "") -> List[NftType]:
         if address == "":
-            address = self.get_signer_address()
+            address = self.__get_signer_address()
 
         balance = self.__abi_module.balance_of.call(address)
         owned_tokens = [self.__token_of_owner_by_index(address, i) for i in range(balance)]
@@ -143,7 +144,7 @@ class NftModule(BaseModule):
     Returns balance of the current signers wallet
     """
     def balance(self) -> int:
-        return self.__abi_module.balance_of.call(self.get_signer_address())
+        return self.__abi_module.balance_of.call(self.__get_signer_address())
 
     def balance_of(self, address: str) -> int:
         return self.__abi_module.balance_of.call(address)
@@ -156,17 +157,22 @@ class NftModule(BaseModule):
     """
     def set_approval(self, operator: str, approved: bool = True):
         self.execute_tx(self.__abi_module.set_approval_for_all.call(
-            operator, approved, self.get_transact_opts()
+            operator, approved, self.__get_transact_opts()
         ))
 
     def grant_role(self, role: Role, address: str):
         role_hash = role.get_hash()
         self.execute_tx(self.__abi_module.grant_role.build_transaction(
-            role_hash, address, self.get_transact_opts()
+            role_hash, address, self.__get_transact_opts()
         ))
 
     def revoke_role(self, role, address: str):
         role_hash = role.get_hash()
         self.execute_tx(self.__abi_module.revoke_role.build_transaction(
-            role_hash, address, self.get_transact_opts()
+            role_hash, address, self.__get_transact_opts()
+        ))
+
+    def set_restricted_transfer(self, restricted: bool = True):
+        self.execute_tx(self.__abi_module.set_restricted_transfer.build_transaction(
+            restricted, self.__get_transact_opts()
         ))
